==> microkit-0.9.9.tgz: package/lib/api/index.js <==
'use strict';

const _ = require('lodash');

const Factory = require('../factory');
const Controller = require('../controller');

const SwaggerApi = require('./swagger');
const RedisApi = require('./redis');
const MethodApi = require('./method');

/**
 * Controller for api services
 * @class
 */
class ApiController extends Controller {
  /**
   * Calls an api
   * @param {string} method method to call
   * @param {object} parame parameters to pass
   * @param {object} options additional options to pass
   */
  call(method, parameters, options) {
    return this.service.call(method, parameters, options);
  }

  dispose() {
    this.service.dispose();
  }

}

class MultyApiController extends Controller {
  call(serviceName, methodName, args, options) {
    const service = _.find(this.service, (v) => {
      return !!v[serviceName];
    });
    if (service[serviceName]) {
      return service[serviceName].service.call(methodName, args, options);
    } else {
      throw new Error('Service not found');
    }
  }
}

class ApiFactory extends Factory {
  get types() {
    const factory = this;
    return {
      swagger: Controller.wrapType(ApiController, SwaggerApi),
      redis: Controller.wrapType(ApiController, RedisApi),
      method: Controller.wrapType(ApiController, MethodApi),
      multy: function (options, context) {
        const apis = _.map(options.apis, (apiOptions, name) => {
          return {
            [name]: factory.create(
              _.get(apiOptions, 'name', name),
              _.omit(apiOptions, 'name'), context
            )
          };
        });
        return new MultyApiController(apis, options);
      }
    };
  }
}

module.exports = ApiFactory;

==> microkit-0.12.2.tgz: package/lib/api/index.js <==
'use strict';

const _ = require('lodash');

const Factory = require('../factory');
const Controller = require('../controller');

const SwaggerApi = require('./swagger');
const RedisApi = require('./redis');
const MockApi = require('./mock');

/**
 * Controller for api services
 * @class
 */
class ApiController extends Controller {
  /**
   * Calls an api
   * @param {string} method method to call
   * @param {object} parame parameters to pass
   * @param {object} options additional options to pass
   */
  call(method, parameters, options) {
    return this.service.call(method, parameters, options);
  }

  dispose() {
    this.service.dispose();
  }

}

class MultyApiController extends Controller {
  call(serviceName, methodName, args, options) {
    if (this.services[serviceName]) {
      return this.services[serviceName].service.call(methodName, args, options);
    } else {
      throw new Error('Service not found');
    }
  }

  get services() {
    return this.service;
  }
}

class ApiFactory extends Factory {
  get types() {
    const factory = this;
    return {
      swagger: Controller.wrapType(ApiController, SwaggerApi),
      redis: Controller.wrapType(ApiController, RedisApi),
      mock: Controller.wrapType(ApiController, MockApi),
      multy: function (options, context) {
        const apis = _.mapValues(options.apis, (apiOptions, name) => {
          return factory.create(
            _.get(apiOptions, 'name', name),
            _.omit(apiOptions, 'name'),
            context
          );
        });
        return new MultyApiController(apis, options);
      }
    };
  }
}

module.exports = ApiFactory;
